@@ -1253,10 +1253,17 @@ static void copy(const char * in, const char * out, const char * magic)
     {
         fwrite(buffer, 1, len, outFp);
     }
+    fclose(inFp);
+    fclose(outFp);
 }
 
 /**
  * Install the plugin
+ *
+ * @param[in] localPluginDir The directory to place the plugin
+ * @param[in] cfgIdx The config idx number
+ * @param[in] pluginIdx The plugin idx number
+ *
  */
 void install(const char * localPluginDir, int cfgIdx, int pluginIdx)
 {
@@ -1352,6 +1359,8 @@ static void write_plugin(const char * config_fname, const char * localPluginDir,
      char buffer[MAX_FILE_PATH_LEN];
      char * path = getProcessedDir();
 
+     install(localPluginDir, cfgIdx, pluginIdx);
+
      LOG_INFO("Creating %s ['%s' @ '%s']\n", localPluginDir, plugin->name, plugin->version);
 
      snprintf(buffer, sizeof(buffer), "%s/%i.helpers", path, cfgIdx);
@@ -1390,8 +1399,7 @@ static void write_plugin(const char * config_fname, const char * localPluginDir,
 
      fclose(fp2);
      fclose(fp1);
-
-     install(localPluginDir, cfgIdx, pluginIdx);
+     free(path);
 }
 
 /**
@@ -1506,6 +1514,6 @@ int main(int argc, char * argv[])
 
      delete_cache();
 
-     return 1;
+     return EXIT_SUCCESS;
 }
 
