@@ -144,7 +144,7 @@ typedef struct handle
 static char errMsg[512];
 static handler_t * g_handlers = 0;
 
-static const char * g_pluginName = "MozPlugger Plugin";
+static const char * g_pluginName = "MozPlugger dummy Plugin";
 static const char * g_version = VERSION;
 static const char * g_linker = NULL;
 static const char * g_controller = NULL;
@@ -1209,15 +1209,21 @@ static command_t * find_command(const data_t * THIS, int streamOnly)
 const char * NP2_GetPluginVersion(const char * magic)
 {
      D("NP_GetPluginVersion(%s)\n", magic);
-     get_helper_paths(magic);
+     if(magic[0] != '-')
+     {
+          get_helper_paths(magic);
+     }
      return g_version;
 }
 
 /**
  * Rebuild the cached versions of configuration
+ *
+ * @return true if success.
  */
-static void mozplugger_update(void)
+static bool mozplugger_update(void)
 {
+     bool success = true;
      pid_t pid;
 
      D("Called mozplugger_update\n");
@@ -1235,9 +1241,61 @@ static void mozplugger_update(void)
      else
      {
          int status;
-         waitpid(pid, &status, 0);
+         waitpid(pid, &status, 0);          /* If Application completed is a bad way, then lets give up now */
+         if(!WIFEXITED(status))
+         {
+               D("mozplugger-update dumped core or something...\n");
+               success = false;
+         }
+         else if(WEXITSTATUS(status) != EXIT_SUCCESS)
+         {
+               D("mozplugger-update exited with status: %d\n", WEXITSTATUS(status));
+               success = false;
+         }
      }
-     NPN_ReloadPlugins(false);
+     if(success)
+     {
+         NPN_ReloadPlugins(false);
+     }
+     return success;
+}
+
+static bool chkValidLocalPluginDirs()
+{
+     static const char * browsers[] =
+     {
+          "%s/.mozilla/plugins",
+          "%s/.netscape/plugins",
+          "%s/.opera/plugins"
+     };
+
+     const char * home = getenv("HOME");
+     int i;
+
+     if(home == NULL)
+     {
+           D("HOME not defined\n");
+           return false;
+     }
+
+     for(i = 0; i < sizeof(browsers)/sizeof(const char *); i++)
+     {
+          struct stat details;
+          char fname[256];
+          int n = snprintf(fname, sizeof(fname), browsers[i], home);
+
+          if( (mkdir(fname, S_IRWXU) != 0) && (errno != EEXIST))
+          {
+               continue;
+          }
+
+          strncat(fname, "/mozplugger0.so", sizeof(fname) - n);
+          if(stat(fname, &details) != 0)
+          {
+               return false;
+          }
+     }
+     return true;
 }
 
 /**
@@ -1257,6 +1315,13 @@ const char * NP2_GetMIMEDescription(const char * magic)
 
      D("NP_GetMIMEDescription(%s)\n", magic);
 
+     if(!chkValidLocalPluginDirs())
+     {
+          D("Local plugin dirs not valid");
+          desc = "dummy/dummy:*.dummy:Dummy";
+          update = true;
+     }
+
      fname = get_mimetypes_cfg_path(magic);
 
      D("Reading '%s'\n", fname);
@@ -1316,7 +1381,10 @@ const char * NP2_GetMIMEDescription(const char * magic)
 
      if(update)
      {
-          mozplugger_update();
+          if(!mozplugger_update() && !desc)
+          {
+               desc = "dummy/dummy:*.dummy:Dummy";
+          }     
      }
 
      D("Getmimedescription done: %s\n", desc);
@@ -1347,10 +1415,18 @@ bool is_playing(NPP instance)
      return false;
 }
 
+/**
+ * Get the name of the plugin
+ *
+ * @param[in] magic references for this particular plugin type
+ */
 static const char * getPluginName(const char * magic)
 {
-    get_helper_paths(magic);
-    return g_pluginName;
+     if(magic[0] != '-')
+     {
+          get_helper_paths(magic);
+     }
+     return g_pluginName;
 }
 
 /**
